"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import core.mgmt.v1beta.metric_pb2
import core.mgmt.v1beta.mgmt_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class MgmtPublicServiceStub:
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LivenessRequest,
        core.mgmt.v1beta.mgmt_pb2.LivenessResponse,
    ]
    """Check if the MGMT server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ReadinessRequest,
        core.mgmt.v1beta.mgmt_pb2.ReadinessResponse,
    ]
    """Check if the pipeline server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    GetAuthenticatedUser: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserRequest,
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserResponse,
    ]
    """Get the authenticated user

    Returns the details of the authenticated user.
    """
    PatchAuthenticatedUser: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserRequest,
        core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserResponse,
    ]
    """Update the authenticated user

    Updates the information of the authenticated user.

    In REST requests, only the supplied user fields will be taken into account
    when updating the resource.
    """
    ListUsers: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersResponse,
    ]
    """List users

    Returns a paginated list of users.
    """
    GetUser: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserResponse,
    ]
    """Get a user

    Returns the details of a user by their ID.
    """
    CreateOrganization: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CreateOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.CreateOrganizationResponse,
    ]
    """Create an organization

    Creates an organization.
    """
    ListOrganizations: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsResponse,
    ]
    """List organizations

    Returns a paginated list of organizations.
    """
    GetOrganization: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationResponse,
    ]
    """Get an organization

    Returns the organization details by its ID.
    """
    UpdateOrganization: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationResponse,
    ]
    """Update an organization

    Accesses and updates an organization by ID.

    In REST requests, only the supplied organization fields will be taken into
    account when updating the resource.
    """
    DeleteOrganization: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationResponse,
    ]
    """Delete an organization

    Accesses and deletes an organization by ID.
    """
    ListUserMemberships: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsResponse,
    ]
    """List user memberships

    Returns the memberships of a user.
    """
    GetUserMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserMembershipResponse,
    ]
    """Get a user membership

    Returns the details of the relationship between a user and an
    organization. The authenticated must match the membership parent.
    """
    UpdateUserMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipResponse,
    ]
    """Update a user membership

    Accesses and updates a user membership by parent and membership IDs.
    """
    DeleteUserMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipResponse,
    ]
    """Delete a user membership

    Accesses and deletes a user membership by parent and membership IDs.
    """
    ListOrganizationMemberships: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsResponse,
    ]
    """List organization memberships

    Returns a paginated list of the user memberships in an organization.
    """
    GetOrganizationMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipResponse,
    ]
    """Get a an organization membership

    Returns the details of a user membership within an organization.
    """
    UpdateOrganizationMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipResponse,
    ]
    """Uppdate an organization membership

    Updates a user membership within an organization.
    """
    DeleteOrganizationMembership: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipResponse,
    ]
    """Delete an organization membership

    Deletes a user membership within an organization.
    """
    GetAuthenticatedUserSubscription: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionRequest,
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionResponse,
    ]
    """Get the subscription of the authenticated user

    Returns the subscription details of the authenticated user.
    """
    GetOrganizationSubscription: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionResponse,
    ]
    """Get the subscription of an organization

    Returns the subscription details of an organization.
    """
    CreateToken: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CreateTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.CreateTokenResponse,
    ]
    """Create an API token

    Creates an API token for the authenticated user.
    """
    ListTokens: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListTokensRequest,
        core.mgmt.v1beta.mgmt_pb2.ListTokensResponse,
    ]
    """List API tokens

    Returns a paginated list of the API tokens of the authenticated user.
    """
    GetToken: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.GetTokenResponse,
    ]
    """Get an API token

    Returns the details of an API token.
    """
    DeleteToken: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteTokenResponse,
    ]
    """Delete an API token

    Deletes an API token.
    """
    ValidateToken: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ValidateTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.ValidateTokenResponse,
    ]
    """Validate an API token

    Validates an API token.
    """
    GetRemainingCredit: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditRequest,
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditResponse,
    ]
    """Get the remaining Instill Credit

    This endpoint returns the remaining [Instill Credit](https://www.instill.tech/docs/vdp/credit) of a given user or
    organization. The requested credit owner must be either the authenticated
    user or an organization they belong to.

    On Instill Core, this endpoint will return a 404 Not Found status.
    """
    CheckNamespace: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceResponse,
    ]
    """Check if a namespace is in use

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """
    GetPipelineTriggerCount: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountRequest,
        core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountResponse,
    ]
    """Get pipeline trigger count

    Returns the pipeline trigger count of a given requester within a timespan.
    Results are grouped by trigger status.
    """
    ListPipelineTriggerTableRecords: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsResponse,
    ]
    """List pipeline trigger metrics

    Returns a paginated list of pipeline executions aggregated by pipeline ID.
    NOTE: This method is deprecated and will be retired soon.
    """
    ListPipelineTriggerChartRecords: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsResponse,
    ]
    """List pipeline trigger time charts

    Returns a timeline of pipline trigger counts for the pipelines of a given
    owner.
    NOTE: This method will soon return the trigger counts of a given requester.
    """
    ListCreditConsumptionChartRecords: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsResponse,
    ]
    """List Instill Credit consumption time charts

    Returns a timeline of Instill Credit consumption for a given owner. The
    response will contain one set of records (datapoints) per consumption
    source (e.g. "pipeline", "model"). Each datapoint represents the amount
    consumed in a time bucket.
    """
    AuthTokenIssuer: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerResponse,
    ]
    """Auth endpoints are only used in the community edition and the OpenAPI
    documentation references Instill Cloud. Therefore, these endpoints are
    hidden.

    Get Auth token issuer

    Returns the auth token issuer details. This operation requires admin permissions.
    """
    AuthLogin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthLoginRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthLoginResponse,
    ]
    """Log in a user

    Authenticates a user and returns an access token.
    """
    AuthLogout: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthLogoutRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthLogoutResponse,
    ]
    """Log out a user

    Logs out an authenticated user.
    """
    AuthChangePassword: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordResponse,
    ]
    """Change password

    Updates the password of a user.
    """
    AuthValidateAccessToken: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenResponse,
    ]
    """Validate an access token

    Checks the validity of an access token.
    """

class MgmtPublicServiceAsyncStub:
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LivenessRequest,
        core.mgmt.v1beta.mgmt_pb2.LivenessResponse,
    ]
    """Check if the MGMT server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ReadinessRequest,
        core.mgmt.v1beta.mgmt_pb2.ReadinessResponse,
    ]
    """Check if the pipeline server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    GetAuthenticatedUser: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserRequest,
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserResponse,
    ]
    """Get the authenticated user

    Returns the details of the authenticated user.
    """
    PatchAuthenticatedUser: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserRequest,
        core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserResponse,
    ]
    """Update the authenticated user

    Updates the information of the authenticated user.

    In REST requests, only the supplied user fields will be taken into account
    when updating the resource.
    """
    ListUsers: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersResponse,
    ]
    """List users

    Returns a paginated list of users.
    """
    GetUser: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserResponse,
    ]
    """Get a user

    Returns the details of a user by their ID.
    """
    CreateOrganization: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CreateOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.CreateOrganizationResponse,
    ]
    """Create an organization

    Creates an organization.
    """
    ListOrganizations: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsResponse,
    ]
    """List organizations

    Returns a paginated list of organizations.
    """
    GetOrganization: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationResponse,
    ]
    """Get an organization

    Returns the organization details by its ID.
    """
    UpdateOrganization: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationResponse,
    ]
    """Update an organization

    Accesses and updates an organization by ID.

    In REST requests, only the supplied organization fields will be taken into
    account when updating the resource.
    """
    DeleteOrganization: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationResponse,
    ]
    """Delete an organization

    Accesses and deletes an organization by ID.
    """
    ListUserMemberships: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsResponse,
    ]
    """List user memberships

    Returns the memberships of a user.
    """
    GetUserMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserMembershipResponse,
    ]
    """Get a user membership

    Returns the details of the relationship between a user and an
    organization. The authenticated must match the membership parent.
    """
    UpdateUserMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipResponse,
    ]
    """Update a user membership

    Accesses and updates a user membership by parent and membership IDs.
    """
    DeleteUserMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipResponse,
    ]
    """Delete a user membership

    Accesses and deletes a user membership by parent and membership IDs.
    """
    ListOrganizationMemberships: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsResponse,
    ]
    """List organization memberships

    Returns a paginated list of the user memberships in an organization.
    """
    GetOrganizationMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipResponse,
    ]
    """Get a an organization membership

    Returns the details of a user membership within an organization.
    """
    UpdateOrganizationMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipResponse,
    ]
    """Uppdate an organization membership

    Updates a user membership within an organization.
    """
    DeleteOrganizationMembership: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipResponse,
    ]
    """Delete an organization membership

    Deletes a user membership within an organization.
    """
    GetAuthenticatedUserSubscription: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionRequest,
        core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionResponse,
    ]
    """Get the subscription of the authenticated user

    Returns the subscription details of the authenticated user.
    """
    GetOrganizationSubscription: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionResponse,
    ]
    """Get the subscription of an organization

    Returns the subscription details of an organization.
    """
    CreateToken: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CreateTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.CreateTokenResponse,
    ]
    """Create an API token

    Creates an API token for the authenticated user.
    """
    ListTokens: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListTokensRequest,
        core.mgmt.v1beta.mgmt_pb2.ListTokensResponse,
    ]
    """List API tokens

    Returns a paginated list of the API tokens of the authenticated user.
    """
    GetToken: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.GetTokenResponse,
    ]
    """Get an API token

    Returns the details of an API token.
    """
    DeleteToken: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.DeleteTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.DeleteTokenResponse,
    ]
    """Delete an API token

    Deletes an API token.
    """
    ValidateToken: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ValidateTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.ValidateTokenResponse,
    ]
    """Validate an API token

    Validates an API token.
    """
    GetRemainingCredit: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditRequest,
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditResponse,
    ]
    """Get the remaining Instill Credit

    This endpoint returns the remaining [Instill Credit](https://www.instill.tech/docs/vdp/credit) of a given user or
    organization. The requested credit owner must be either the authenticated
    user or an organization they belong to.

    On Instill Core, this endpoint will return a 404 Not Found status.
    """
    CheckNamespace: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceResponse,
    ]
    """Check if a namespace is in use

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """
    GetPipelineTriggerCount: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountRequest,
        core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountResponse,
    ]
    """Get pipeline trigger count

    Returns the pipeline trigger count of a given requester within a timespan.
    Results are grouped by trigger status.
    """
    ListPipelineTriggerTableRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsResponse,
    ]
    """List pipeline trigger metrics

    Returns a paginated list of pipeline executions aggregated by pipeline ID.
    NOTE: This method is deprecated and will be retired soon.
    """
    ListPipelineTriggerChartRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsResponse,
    ]
    """List pipeline trigger time charts

    Returns a timeline of pipline trigger counts for the pipelines of a given
    owner.
    NOTE: This method will soon return the trigger counts of a given requester.
    """
    ListCreditConsumptionChartRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsRequest,
        core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsResponse,
    ]
    """List Instill Credit consumption time charts

    Returns a timeline of Instill Credit consumption for a given owner. The
    response will contain one set of records (datapoints) per consumption
    source (e.g. "pipeline", "model"). Each datapoint represents the amount
    consumed in a time bucket.
    """
    AuthTokenIssuer: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerResponse,
    ]
    """Auth endpoints are only used in the community edition and the OpenAPI
    documentation references Instill Cloud. Therefore, these endpoints are
    hidden.

    Get Auth token issuer

    Returns the auth token issuer details. This operation requires admin permissions.
    """
    AuthLogin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthLoginRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthLoginResponse,
    ]
    """Log in a user

    Authenticates a user and returns an access token.
    """
    AuthLogout: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthLogoutRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthLogoutResponse,
    ]
    """Log out a user

    Logs out an authenticated user.
    """
    AuthChangePassword: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordResponse,
    ]
    """Change password

    Updates the password of a user.
    """
    AuthValidateAccessToken: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenRequest,
        core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenResponse,
    ]
    """Validate an access token

    Checks the validity of an access token.
    """

class MgmtPublicServiceServicer(metaclass=abc.ABCMeta):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.LivenessResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.LivenessResponse]]:
        """Check if the MGMT server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ReadinessResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ReadinessResponse]]:
        """Check if the pipeline server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def GetAuthenticatedUser(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserResponse]]:
        """Get the authenticated user

        Returns the details of the authenticated user.
        """
    @abc.abstractmethod
    def PatchAuthenticatedUser(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.PatchAuthenticatedUserResponse]]:
        """Update the authenticated user

        Updates the information of the authenticated user.

        In REST requests, only the supplied user fields will be taken into account
        when updating the resource.
        """
    @abc.abstractmethod
    def ListUsers(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListUsersRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListUsersResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListUsersResponse]]:
        """List users

        Returns a paginated list of users.
        """
    @abc.abstractmethod
    def GetUser(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserResponse]]:
        """Get a user

        Returns the details of a user by their ID.
        """
    @abc.abstractmethod
    def CreateOrganization(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.CreateOrganizationRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.CreateOrganizationResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.CreateOrganizationResponse]]:
        """Create an organization

        Creates an organization.
        """
    @abc.abstractmethod
    def ListOrganizations(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListOrganizationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsResponse]]:
        """List organizations

        Returns a paginated list of organizations.
        """
    @abc.abstractmethod
    def GetOrganization(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationResponse]]:
        """Get an organization

        Returns the organization details by its ID.
        """
    @abc.abstractmethod
    def UpdateOrganization(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationResponse]]:
        """Update an organization

        Accesses and updates an organization by ID.

        In REST requests, only the supplied organization fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteOrganization(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationResponse]]:
        """Delete an organization

        Accesses and deletes an organization by ID.
        """
    @abc.abstractmethod
    def ListUserMemberships(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListUserMembershipsResponse]]:
        """List user memberships

        Returns the memberships of a user.
        """
    @abc.abstractmethod
    def GetUserMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserMembershipResponse]]:
        """Get a user membership

        Returns the details of the relationship between a user and an
        organization. The authenticated must match the membership parent.
        """
    @abc.abstractmethod
    def UpdateUserMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.UpdateUserMembershipResponse]]:
        """Update a user membership

        Accesses and updates a user membership by parent and membership IDs.
        """
    @abc.abstractmethod
    def DeleteUserMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.DeleteUserMembershipResponse]]:
        """Delete a user membership

        Accesses and deletes a user membership by parent and membership IDs.
        """
    @abc.abstractmethod
    def ListOrganizationMemberships(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListOrganizationMembershipsResponse]]:
        """List organization memberships

        Returns a paginated list of the user memberships in an organization.
        """
    @abc.abstractmethod
    def GetOrganizationMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationMembershipResponse]]:
        """Get a an organization membership

        Returns the details of a user membership within an organization.
        """
    @abc.abstractmethod
    def UpdateOrganizationMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.UpdateOrganizationMembershipResponse]]:
        """Uppdate an organization membership

        Updates a user membership within an organization.
        """
    @abc.abstractmethod
    def DeleteOrganizationMembership(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.DeleteOrganizationMembershipResponse]]:
        """Delete an organization membership

        Deletes a user membership within an organization.
        """
    @abc.abstractmethod
    def GetAuthenticatedUserSubscription(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetAuthenticatedUserSubscriptionResponse]]:
        """Get the subscription of the authenticated user

        Returns the subscription details of the authenticated user.
        """
    @abc.abstractmethod
    def GetOrganizationSubscription(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionResponse]]:
        """Get the subscription of an organization

        Returns the subscription details of an organization.
        """
    @abc.abstractmethod
    def CreateToken(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.CreateTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.CreateTokenResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.CreateTokenResponse]]:
        """Create an API token

        Creates an API token for the authenticated user.
        """
    @abc.abstractmethod
    def ListTokens(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListTokensRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListTokensResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListTokensResponse]]:
        """List API tokens

        Returns a paginated list of the API tokens of the authenticated user.
        """
    @abc.abstractmethod
    def GetToken(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetTokenResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetTokenResponse]]:
        """Get an API token

        Returns the details of an API token.
        """
    @abc.abstractmethod
    def DeleteToken(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.DeleteTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.DeleteTokenResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.DeleteTokenResponse]]:
        """Delete an API token

        Deletes an API token.
        """
    @abc.abstractmethod
    def ValidateToken(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ValidateTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ValidateTokenResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ValidateTokenResponse]]:
        """Validate an API token

        Validates an API token.
        """
    @abc.abstractmethod
    def GetRemainingCredit(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditResponse]]:
        """Get the remaining Instill Credit

        This endpoint returns the remaining [Instill Credit](https://www.instill.tech/docs/vdp/credit) of a given user or
        organization. The requested credit owner must be either the authenticated
        user or an organization they belong to.

        On Instill Core, this endpoint will return a 404 Not Found status.
        """
    @abc.abstractmethod
    def CheckNamespace(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.CheckNamespaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceResponse]]:
        """Check if a namespace is in use

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
    @abc.abstractmethod
    def GetPipelineTriggerCount(
        self,
        request: core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountResponse, collections.abc.Awaitable[core.mgmt.v1beta.metric_pb2.GetPipelineTriggerCountResponse]]:
        """Get pipeline trigger count

        Returns the pipeline trigger count of a given requester within a timespan.
        Results are grouped by trigger status.
        """
    @abc.abstractmethod
    def ListPipelineTriggerTableRecords(
        self,
        request: core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsResponse, collections.abc.Awaitable[core.mgmt.v1beta.metric_pb2.ListPipelineTriggerTableRecordsResponse]]:
        """List pipeline trigger metrics

        Returns a paginated list of pipeline executions aggregated by pipeline ID.
        NOTE: This method is deprecated and will be retired soon.
        """
    @abc.abstractmethod
    def ListPipelineTriggerChartRecords(
        self,
        request: core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsResponse, collections.abc.Awaitable[core.mgmt.v1beta.metric_pb2.ListPipelineTriggerChartRecordsResponse]]:
        """List pipeline trigger time charts

        Returns a timeline of pipline trigger counts for the pipelines of a given
        owner.
        NOTE: This method will soon return the trigger counts of a given requester.
        """
    @abc.abstractmethod
    def ListCreditConsumptionChartRecords(
        self,
        request: core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsResponse, collections.abc.Awaitable[core.mgmt.v1beta.metric_pb2.ListCreditConsumptionChartRecordsResponse]]:
        """List Instill Credit consumption time charts

        Returns a timeline of Instill Credit consumption for a given owner. The
        response will contain one set of records (datapoints) per consumption
        source (e.g. "pipeline", "model"). Each datapoint represents the amount
        consumed in a time bucket.
        """
    @abc.abstractmethod
    def AuthTokenIssuer(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.AuthTokenIssuerResponse]]:
        """Auth endpoints are only used in the community edition and the OpenAPI
        documentation references Instill Cloud. Therefore, these endpoints are
        hidden.

        Get Auth token issuer

        Returns the auth token issuer details. This operation requires admin permissions.
        """
    @abc.abstractmethod
    def AuthLogin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.AuthLoginRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.AuthLoginResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.AuthLoginResponse]]:
        """Log in a user

        Authenticates a user and returns an access token.
        """
    @abc.abstractmethod
    def AuthLogout(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.AuthLogoutRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.AuthLogoutResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.AuthLogoutResponse]]:
        """Log out a user

        Logs out an authenticated user.
        """
    @abc.abstractmethod
    def AuthChangePassword(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.AuthChangePasswordResponse]]:
        """Change password

        Updates the password of a user.
        """
    @abc.abstractmethod
    def AuthValidateAccessToken(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.AuthValidateAccessTokenResponse]]:
        """Validate an access token

        Checks the validity of an access token.
        """

def add_MgmtPublicServiceServicer_to_server(servicer: MgmtPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7artifact/artifact/v1alpha/artifact_public_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a%artifact/artifact/v1alpha/chunk.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xe0\x17\n\x15\x41rtifactPublicService\x12\xac\x01\n\x08Liveness\x12*.artifact.artifact.v1alpha.LivenessRequest\x1a+.artifact.artifact.v1alpha.LivenessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x13/v1alpha/__livenessZ\x1a\x12\x18/v1alpha/health/artifact\x12\xaf\x01\n\tReadiness\x12+.artifact.artifact.v1alpha.ReadinessRequest\x1a,.artifact.artifact.v1alpha.ReadinessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x14/v1alpha/__readinessZ\x19\x12\x17/v1alpha/ready/artifact\x12\xd5\x01\n\x13\x43reateKnowledgeBase\x12\x35.artifact.artifact.v1alpha.CreateKnowledgeBaseRequest\x1a\x36.artifact.artifact.v1alpha.CreateKnowledgeBaseResponse\"O\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02\x37\"2/v1alpha/namespaces/{namespace_id}/knowledge-bases:\x01*\x12\xcf\x01\n\x12ListKnowledgeBases\x12\x34.artifact.artifact.v1alpha.ListKnowledgeBasesRequest\x1a\x35.artifact.artifact.v1alpha.ListKnowledgeBasesResponse\"L\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/namespaces/{namespace_id}/knowledge-bases\x12\xdd\x01\n\x13UpdateKnowledgeBase\x12\x35.artifact.artifact.v1alpha.UpdateKnowledgeBaseRequest\x1a\x36.artifact.artifact.v1alpha.UpdateKnowledgeBaseResponse\"W\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02?\x1a:/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}:\x01*\x12\xda\x01\n\x13\x44\x65leteKnowledgeBase\x12\x35.artifact.artifact.v1alpha.DeleteKnowledgeBaseRequest\x1a\x36.artifact.artifact.v1alpha.DeleteKnowledgeBaseResponse\"T\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02<*:/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}\x12\xf2\x01\n\x17UploadKnowledgeBaseFile\x12\x39.artifact.artifact.v1alpha.UploadKnowledgeBaseFileRequest\x1a:.artifact.artifact.v1alpha.UploadKnowledgeBaseFileResponse\"`\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02H\"@/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files:\x04\x66ile\x12\xca\x01\n\x17\x44\x65leteKnowledgeBaseFile\x12\x39.artifact.artifact.v1alpha.DeleteKnowledgeBaseFileRequest\x1a:.artifact.artifact.v1alpha.DeleteKnowledgeBaseFileResponse\"8\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/knowledge-bases/files\x12\xe0\x01\n\x19ProcessKnowledgeBaseFiles\x12;.artifact.artifact.v1alpha.ProcessKnowledgeBaseFilesRequest\x1a<.artifact.artifact.v1alpha.ProcessKnowledgeBaseFilesResponse\"H\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02\x30\"+/v1alpha/knowledge-bases/files/processAsync:\x01*\x12\xe9\x01\n\x16ListKnowledgeBaseFiles\x12\x38.artifact.artifact.v1alpha.ListKnowledgeBaseFilesRequest\x1a\x39.artifact.artifact.v1alpha.ListKnowledgeBaseFilesResponse\"Z\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02\x42\x12@/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files\x12\xc6\x01\n\nListChunks\x12,.artifact.artifact.v1alpha.ListChunksRequest\x1a-.artifact.artifact.v1alpha.ListChunksResponse\"[\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02\x43\x12\x41/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/chunks\x12\xe0\x01\n\rGetSourceFile\x12/.artifact.artifact.v1alpha.GetSourceFileRequest\x1a\x30.artifact.artifact.v1alpha.GetSourceFileResponse\"l\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02T\x12R/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files/{file_uid}/source\x12\xa6\x01\n\x0bUpdateChunk\x12-.artifact.artifact.v1alpha.UpdateChunkRequest\x1a..artifact.artifact.v1alpha.UpdateChunkResponse\"8\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02 \"\x1b/v1alpha/chunks/{chunk_uid}:\x01*\x12\xf8\x01\n\x16SimilarityChunksSearch\x12\x38.artifact.artifact.v1alpha.SimilarityChunksSearchRequest\x1a\x39.artifact.artifact.v1alpha.SimilarityChunksSearchResponse\"i\x92\x41\x0f\n\rKnowledgeBase\x82\xd3\xe4\x93\x02Q\"L/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/chunks/similarity:\x01*\x1a\x1e\x92\x41\x1b\x12\x19Public Artifact endpointsB\x8e\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1a\x41rtifactPublicServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\032ArtifactPublicServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _ARTIFACTPUBLICSERVICE._options = None
  _ARTIFACTPUBLICSERVICE._serialized_options = b'\222A\033\022\031Public Artifact endpoints'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\023/v1alpha/__livenessZ\032\022\030/v1alpha/health/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\024/v1alpha/__readinessZ\031\022\027/v1alpha/ready/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateKnowledgeBase']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateKnowledgeBase']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\0027\"2/v1alpha/namespaces/{namespace_id}/knowledge-bases:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListKnowledgeBases']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListKnowledgeBases']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\0024\0222/v1alpha/namespaces/{namespace_id}/knowledge-bases'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateKnowledgeBase']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateKnowledgeBase']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002?\032:/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteKnowledgeBase']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteKnowledgeBase']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002<*:/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadKnowledgeBaseFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadKnowledgeBaseFile']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002H\"@/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files:\004file'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteKnowledgeBaseFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteKnowledgeBaseFile']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002 *\036/v1alpha/knowledge-bases/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessKnowledgeBaseFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessKnowledgeBaseFiles']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\0020\"+/v1alpha/knowledge-bases/files/processAsync:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListKnowledgeBaseFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListKnowledgeBaseFiles']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002B\022@/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002C\022A/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/chunks'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002T\022R/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/files/{file_uid}/source'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002 \"\033/v1alpha/chunks/{chunk_uid}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._serialized_options = b'\222A\017\n\rKnowledgeBase\202\323\344\223\002Q\"L/v1alpha/namespaces/{namespace_id}/knowledge-bases/{kb_id}/chunks/similarity:\001*'
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_start=275
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_end=3315
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Mode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Mode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODE_UNSPECIFIED: _Mode.ValueType  # 0
    """Unspecified."""
    MODE_SYNC: _Mode.ValueType  # 1
    """Synchronous (result is returned in the response)."""
    MODE_ASYNC: _Mode.ValueType  # 2
    """Asynchronous (response only contains acknowledgement)."""

class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
    """Mode describes the execution mode of the pipeline (sync or async)."""

MODE_UNSPECIFIED: Mode.ValueType  # 0
"""Unspecified."""
MODE_SYNC: Mode.ValueType  # 1
"""Synchronous (result is returned in the response)."""
MODE_ASYNC: Mode.ValueType  # 2
"""Asynchronous (response only contains acknowledgement)."""
global___Mode = Mode

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """Unspecified."""
    STATUS_COMPLETED: _Status.ValueType  # 1
    """Successfully completed."""
    STATUS_ERRORED: _Status.ValueType  # 2
    """Finished with error."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper):
    """Status describes the output of an execution."""

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""Unspecified."""
STATUS_COMPLETED: Status.ValueType  # 1
"""Successfully completed."""
STATUS_ERRORED: Status.ValueType  # 2
"""Finished with error."""
global___Status = Status

@typing_extensions.final
class PipelineTriggerCount(google.protobuf.message.Message):
    """========== Pipeline endpoints

    PipelineTriggerCount represents a pipeline execution count with some
    aggregation params (e.g. trigger status).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_COUNT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    trigger_count: builtins.int
    """Number of triggers."""
    status: global___Status.ValueType
    """This field will be present when results are grouped by trigger status."""
    def __init__(
        self,
        *,
        trigger_count: builtins.int = ...,
        status: global___Status.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_status", b"_status", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_status", b"_status", "status", b"status", "trigger_count", b"trigger_count"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_status", b"_status"]) -> typing_extensions.Literal["status"] | None: ...

global___PipelineTriggerCount = PipelineTriggerCount

@typing_extensions.final
class GetPipelineTriggerCountRequest(google.protobuf.message.Message):
    """
    // PipelineTriggerChartRecord represents a timeline of pipeline triggers. It
    // contains a collection of (timestamp, count) pairs that represent the total
    // pipeline triggers in a given time bucket.
    // pipeline ID and time frame.
    message PipelineTriggerChartRecord {
    // This field will be present present when the information is grouped by pipeline.
    optional string pipeline_id = 1 [(google.api.field_behavior) = OUTPUT_ONLY];
    // 2 is reserved for the pipeline UUID.
    reserved 2;
    // 3 is reserved for the trigger mode. The server wasn't grouping results by this
    // field.
    reserved 3;
    // 4 is reserved for the trigger status. The server wasn't grouping results
    // by this field.
    reserved 4;
    // Time buckets.
    repeated google.protobuf.Timestamp time_buckets = 5 [(google.api.field_behavior) = OUTPUT_ONLY];
    // Aggregated trigger count in each time bucket.
    repeated int32 trigger_counts = 6 [(google.api.field_behavior) = OUTPUT_ONLY];
    // 7 is reserved for the trigger execution duration.
    reserved 7;
    // 8 is reserved for the pipeline release ID. The server wasn't grouping
    // results by this field.
    reserved 8;
    // 9 is reserved for the pipeline release UUID. The server wasn't grouping
    // results by this field.
    reserved 9;
    // The ID of the namespace that requested the pipeline triggers.
    string namespace_id = 10 [(google.api.field_behavior) = OUTPUT_ONLY];
    }

    GetPipelineTriggerCountRequest represents a request to fetch the trigger
    count of a requester over a time period.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the namespace that requested the pipeline triggers."""
    @property
    def start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Beginning of the time range from which the records will be fetched.
        The default value is the beginning of the current day, in UTC.
        """
    @property
    def stop(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the time range from which the records will be fetched.
        The default value is the current timestamp.
        """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        stop: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_start", b"_start", "_stop", b"_stop", "start", b"start", "stop", b"stop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_start", b"_start", "_stop", b"_stop", "namespace_id", b"namespace_id", "start", b"start", "stop", b"stop"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_start", b"_start"]) -> typing_extensions.Literal["start"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_stop", b"_stop"]) -> typing_extensions.Literal["stop"] | None: ...

global___GetPipelineTriggerCountRequest = GetPipelineTriggerCountRequest

@typing_extensions.final
class GetPipelineTriggerCountResponse(google.protobuf.message.Message):
    """GetPipelineTriggerCountResponse contains the trigger count, grouped by
    trigger status.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_COUNTS_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_counts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerCount]:
        """The trigger counts, grouped by status."""
    def __init__(
        self,
        *,
        pipeline_trigger_counts: collections.abc.Iterable[global___PipelineTriggerCount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_trigger_counts", b"pipeline_trigger_counts"]) -> None: ...

global___GetPipelineTriggerCountResponse = GetPipelineTriggerCountResponse

@typing_extensions.final
class CreditConsumptionChartRecord(google.protobuf.message.Message):
    """
    // ListPipelineTriggerChartRecordsRequest represents a request to list pipeline
    // trigger chart records for a given requester, grouped by time buckets.
    message ListPipelineTriggerChartRecordsRequest {
    // 1 is reserved for the aggregation window in nanoseconds. This is
    // deprecated in favour of an aggregation window string that represents a
    // duration.
    reserved 1;
    // 2 is reserved for the filter. For now, this endpoint won't allow filtering
    // but in the future we might implement a filter to show the trigger count of
    // only certain pipelines and to group by the pipeline ID.
    reserved 2;

    // The ID of the namespace that requested the pipeline triggers.
    string namespace_id = 3 [(google.api.field_behavior) = REQUIRED];
    // Aggregation window. The value is a positive duration string, i.e. a
    // sequence of decimal numbers, each with optional fraction and a unit
    // suffix, such as "300ms", "1.5h" or "2h45m".
    // The minimum (and default) window is 1h.
    optional string aggregation_window = 4;
    // Beginning of the time range from which the records will be fetched.
    // The default value is the beginning of the current day, in UTC.
    optional google.protobuf.Timestamp start = 5;
    // End of the time range from which the records will be fetched.
    // The default value is the current timestamp.
    optional google.protobuf.Timestamp stop = 6;
    }

    // ListPipelineTriggerChartRecordsResponse contains a list of pipeline trigger
    // chart records.
    message ListPipelineTriggerChartRecordsResponse {
    // Pipeline trigger counts. Until we allow filtering or grouping by fields
    // like pipeline ID, this list will contain only one element with the
    // timeline of trigger counts for a given requester, regardless the pipeline
    // ID, trigger mode, final status or other fields.
    repeated PipelineTriggerChartRecord pipeline_trigger_chart_records = 1;
    }

    CreditConsumptionChartRecord represents a timeline of Instill Credit
    consumption. It contains a collection of (timestamp, amount) pairs that
    represent the total credit consumption in a given time bucket.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    TIME_BUCKETS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the namespace that owns the credit."""
    @property
    def time_buckets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.timestamp_pb2.Timestamp]:
        """Time buckets."""
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Total credit consumed in each time bucket."""
    source: builtins.str
    """Credit consumption source (e.g. "pipeline", "model")."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        time_buckets: collections.abc.Iterable[google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        amount: collections.abc.Iterable[builtins.float] | None = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "namespace_id", b"namespace_id", "source", b"source", "time_buckets", b"time_buckets"]) -> None: ...

global___CreditConsumptionChartRecord = CreditConsumptionChartRecord

@typing_extensions.final
class ListCreditConsumptionChartRecordsRequest(google.protobuf.message.Message):
    """ListCreditConsumptionChartRecordsRequest represents a request to list credit
    consumption chart records for a given owner, grouped by time buckets and
    consumption sources.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    AGGREGATION_WINDOW_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the namespace that owns the credit."""
    aggregation_window: builtins.str
    """Aggregation window. The value is a positive duration string, i.e. a
    sequence of decimal numbers, each with optional fraction and a unit
    suffix, such as "300ms", "1.5h" or "2h45m".
    The minimum (and default) window is 1h.
    """
    @property
    def start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Beginning of the time range from which the records will be fetched.
        The default value is the beginning of the current day, in UTC.
        """
    @property
    def stop(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the time range from which the records will be fetched.
        The default value is the current timestamp.
        """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        aggregation_window: builtins.str | None = ...,
        start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        stop: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_aggregation_window", b"_aggregation_window", "_start", b"_start", "_stop", b"_stop", "aggregation_window", b"aggregation_window", "start", b"start", "stop", b"stop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_aggregation_window", b"_aggregation_window", "_start", b"_start", "_stop", b"_stop", "aggregation_window", b"aggregation_window", "namespace_id", b"namespace_id", "start", b"start", "stop", b"stop"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_aggregation_window", b"_aggregation_window"]) -> typing_extensions.Literal["aggregation_window"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_start", b"_start"]) -> typing_extensions.Literal["start"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_stop", b"_stop"]) -> typing_extensions.Literal["stop"] | None: ...

global___ListCreditConsumptionChartRecordsRequest = ListCreditConsumptionChartRecordsRequest

@typing_extensions.final
class ListCreditConsumptionChartRecordsResponse(google.protobuf.message.Message):
    """ListCreditConsumptionChartRecordsResponse contains a list of credit consumption
    chart records.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDIT_CONSUMPTION_CHART_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def credit_consumption_chart_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreditConsumptionChartRecord]:
        """Credit consumption timelines, aggregated by source."""
    def __init__(
        self,
        *,
        credit_consumption_chart_records: collections.abc.Iterable[global___CreditConsumptionChartRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["credit_consumption_chart_records", b"credit_consumption_chart_records"]) -> None: ...

global___ListCreditConsumptionChartRecordsResponse = ListCreditConsumptionChartRecordsResponse

@typing_extensions.final
class PipelineTriggerTableRecord(google.protobuf.message.Message):
    """Deprecated messages, to be removed with the new dashboard implementation.

    PipelineTriggerTableRecord contains pipeline trigger metrics, aggregated by
    pipeline ID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    TRIGGER_COUNT_COMPLETED_FIELD_NUMBER: builtins.int
    TRIGGER_COUNT_ERRORED_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    trigger_count_completed: builtins.int
    """Number of triggers with `STATUS_COMPLETED`."""
    trigger_count_errored: builtins.int
    """Number of triggers with `STATUS_ERRORED`."""
    pipeline_release_id: builtins.str
    """Version for the triggered pipeline if it is a release pipeline."""
    pipeline_release_uid: builtins.str
    """Release UUID for the triggered pipeline if it is a release pipeline."""
    def __init__(
        self,
        *,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        trigger_count_completed: builtins.int = ...,
        trigger_count_errored: builtins.int = ...,
        pipeline_release_id: builtins.str = ...,
        pipeline_release_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_uid", b"pipeline_uid", "trigger_count_completed", b"trigger_count_completed", "trigger_count_errored", b"trigger_count_errored"]) -> None: ...

global___PipelineTriggerTableRecord = PipelineTriggerTableRecord

@typing_extensions.final
class ListPipelineTriggerTableRecordsRequest(google.protobuf.message.Message):
    """ListPipelineTriggerTableRecordsRequest represents a request to list the
    pipeline triggers metrics, aggregated by pipeline ID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results to return. If this parameter is unspecified,
    at most 100 pipelines will be returned. The cap value for this parameter
    is 1000 (i.e. any value above that will be coerced to 1000).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListPipelineTriggerTableRecordsRequest = ListPipelineTriggerTableRecordsRequest

@typing_extensions.final
class ListPipelineTriggerTableRecordsResponse(google.protobuf.message.Message):
    """ListPipelineTriggerTableRecordsResponse contains the pipeline metrics."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_TABLE_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_table_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerTableRecord]:
        """A list of pipeline trigger tables."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline trigger records"""
    def __init__(
        self,
        *,
        pipeline_trigger_table_records: collections.abc.Iterable[global___PipelineTriggerTableRecord] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipeline_trigger_table_records", b"pipeline_trigger_table_records", "total_size", b"total_size"]) -> None: ...

global___ListPipelineTriggerTableRecordsResponse = ListPipelineTriggerTableRecordsResponse

@typing_extensions.final
class ListPipelineTriggerChartRecordsRequest(google.protobuf.message.Message):
    """ListPipelineTriggerChartRecordsRequest represents a request to list pipeline
    trigger metrics, aggregated by pipeline ID and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_WINDOW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    aggregation_window: builtins.int
    """Aggregation window in nanoseconds."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        aggregation_window: builtins.int = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "aggregation_window", b"aggregation_window", "filter", b"filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...

global___ListPipelineTriggerChartRecordsRequest = ListPipelineTriggerChartRecordsRequest

@typing_extensions.final
class ListPipelineTriggerChartRecordsResponse(google.protobuf.message.Message):
    """ListPipelineTriggerChartRecordsResponse contains a list of pipeline trigger
    chart records.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_CHART_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_chart_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerChartRecord]:
        """A list of pipeline trigger records."""
    def __init__(
        self,
        *,
        pipeline_trigger_chart_records: collections.abc.Iterable[global___PipelineTriggerChartRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_trigger_chart_records", b"pipeline_trigger_chart_records"]) -> None: ...

global___ListPipelineTriggerChartRecordsResponse = ListPipelineTriggerChartRecordsResponse

@typing_extensions.final
class PipelineTriggerChartRecord(google.protobuf.message.Message):
    """PipelineTriggerChartRecord contains pipeline trigger metrics, aggregated by
    pipeline ID and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    TRIGGER_MODE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TIME_BUCKETS_FIELD_NUMBER: builtins.int
    TRIGGER_COUNTS_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_DURATION_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    trigger_mode: global___Mode.ValueType
    """Trigger mode."""
    status: global___Status.ValueType
    """Final status."""
    @property
    def time_buckets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.timestamp_pb2.Timestamp]:
        """Time buckets."""
    @property
    def trigger_counts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Aggregated trigger count in each time bucket."""
    @property
    def compute_time_duration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Total computation time duration in each time bucket."""
    pipeline_release_id: builtins.str
    """Version for the triggered pipeline if it is a release pipeline."""
    pipeline_release_uid: builtins.str
    """Release UUID for the triggered pipeline if it is a release pipeline."""
    def __init__(
        self,
        *,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        trigger_mode: global___Mode.ValueType = ...,
        status: global___Status.ValueType = ...,
        time_buckets: collections.abc.Iterable[google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        trigger_counts: collections.abc.Iterable[builtins.int] | None = ...,
        compute_time_duration: collections.abc.Iterable[builtins.float] | None = ...,
        pipeline_release_id: builtins.str = ...,
        pipeline_release_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_duration", b"compute_time_duration", "pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_uid", b"pipeline_uid", "status", b"status", "time_buckets", b"time_buckets", "trigger_counts", b"trigger_counts", "trigger_mode", b"trigger_mode"]) -> None: ...

global___PipelineTriggerChartRecord = PipelineTriggerChartRecord



from instill.helpers.protobufs.parse import (
    Metadata,
    construct_image_to_image_infer_response,
    construct_image_to_image_metadata_response,
    construct_infer_response,
    construct_metadata_response,
    construct_text_generation_chat_infer_response,
    construct_text_generation_chat_metadata_response,
    construct_text_generation_infer_response,
    construct_text_generation_metadata_response,
    construct_text_to_image_infer_response,
    construct_text_to_image_metadata_response,
    construct_visual_question_answering_infer_response,
    construct_visual_question_answering_metadata_response,
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import artifact.artifact.v1alpha.artifact_pb2
import artifact.artifact.v1alpha.chunk_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ArtifactPublicServiceStub:
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateKnowledgeBase: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseResponse,
    ]
    """Create a knowledge base"""
    ListKnowledgeBases: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesResponse,
    ]
    """Get all knowledge bases info"""
    UpdateKnowledgeBase: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseResponse,
    ]
    """Update a knowledge base info"""
    DeleteKnowledgeBase: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseResponse,
    ]
    """Delete a knowledge base"""
    UploadKnowledgeBaseFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileResponse,
    ]
    """Create a file"""
    DeleteKnowledgeBaseFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileResponse,
    ]
    """Delete a file"""
    ProcessKnowledgeBaseFiles: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesResponse,
    ]
    """process file"""
    ListKnowledgeBaseFiles: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesResponse,
    ]
    """list files"""
    ListChunks: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse,
    ]
    """List chunks"""
    GetSourceFile: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse,
    ]
    """Get source file"""
    UpdateChunk: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse,
    ]
    """Update chunk"""
    SimilarityChunksSearch: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse,
    ]
    """Similarity chunks search"""

class ArtifactPublicServiceAsyncStub:
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateKnowledgeBase: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseResponse,
    ]
    """Create a knowledge base"""
    ListKnowledgeBases: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesResponse,
    ]
    """Get all knowledge bases info"""
    UpdateKnowledgeBase: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseResponse,
    ]
    """Update a knowledge base info"""
    DeleteKnowledgeBase: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseResponse,
    ]
    """Delete a knowledge base"""
    UploadKnowledgeBaseFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileResponse,
    ]
    """Create a file"""
    DeleteKnowledgeBaseFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileResponse,
    ]
    """Delete a file"""
    ProcessKnowledgeBaseFiles: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesResponse,
    ]
    """process file"""
    ListKnowledgeBaseFiles: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesResponse,
    ]
    """list files"""
    ListChunks: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse,
    ]
    """List chunks"""
    GetSourceFile: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse,
    ]
    """Get source file"""
    UpdateChunk: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse,
    ]
    """Update chunk"""
    SimilarityChunksSearch: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse,
    ]
    """Similarity chunks search"""

class ArtifactPublicServiceServicer(metaclass=abc.ABCMeta):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse]]:
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse]]:
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def CreateKnowledgeBase(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.CreateKnowledgeBaseResponse]]:
        """Create a knowledge base"""
    @abc.abstractmethod
    def ListKnowledgeBases(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBasesResponse]]:
        """Get all knowledge bases info"""
    @abc.abstractmethod
    def UpdateKnowledgeBase(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.UpdateKnowledgeBaseResponse]]:
        """Update a knowledge base info"""
    @abc.abstractmethod
    def DeleteKnowledgeBase(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseResponse]]:
        """Delete a knowledge base"""
    @abc.abstractmethod
    def UploadKnowledgeBaseFile(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.UploadKnowledgeBaseFileResponse]]:
        """Create a file"""
    @abc.abstractmethod
    def DeleteKnowledgeBaseFile(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.DeleteKnowledgeBaseFileResponse]]:
        """Delete a file"""
    @abc.abstractmethod
    def ProcessKnowledgeBaseFiles(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ProcessKnowledgeBaseFilesResponse]]:
        """process file"""
    @abc.abstractmethod
    def ListKnowledgeBaseFiles(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListKnowledgeBaseFilesResponse]]:
        """list files"""
    @abc.abstractmethod
    def ListChunks(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.ListChunksRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.ListChunksResponse]]:
        """List chunks"""
    @abc.abstractmethod
    def GetSourceFile(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.GetSourceFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.GetSourceFileResponse]]:
        """Get source file"""
    @abc.abstractmethod
    def UpdateChunk(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.UpdateChunkRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.UpdateChunkResponse]]:
        """Update chunk"""
    @abc.abstractmethod
    def SimilarityChunksSearch(
        self,
        request: artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunksSearchResponse]]:
        """Similarity chunks search"""

def add_ArtifactPublicServiceServicer_to_server(servicer: ArtifactPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
